==> maven-plugin-tools_3.2.orig.tar.xz: maven-plugin-tools-3.2/maven-plugin-tools-generators/src/main/java/org/apache/maven/tools/plugin/generator/Generator.java <==
package org.apache.maven.tools.plugin.generator;

/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

import org.apache.maven.tools.plugin.PluginToolsRequest;

import java.io.File;

/**
 * Generate something, for instance a plugin report, from a plugin descriptor.
 *
 * @author <a href="mailto:jason@maven.org">Jason van Zyl </a>
 * @version $Id: Generator.java 1343107 2012-05-27 21:35:40Z hboutemy $
 */
public interface Generator
{

    /**
     * Execute the generation for a given plugin descriptor.
     *
     * @param destinationDirectory required
     * @param request required
     * @throws IOException if any
     * 
     * @since 2.5
     */
    void execute( File destinationDirectory, PluginToolsRequest request )
        throws GeneratorException;
}

==> maven-plugin-tools_3.5.orig.tar.xz: maven-plugin-tools-3.5/maven-plugin-tools-generators/src/main/java/org/apache/maven/tools/plugin/generator/Generator.java <==
package org.apache.maven.tools.plugin.generator;

/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

import org.apache.maven.tools.plugin.PluginToolsRequest;

import java.io.File;

/**
 * Generate something, for instance a plugin report, from a plugin descriptor.
 *
 * @author <a href="mailto:jason@maven.org">Jason van Zyl </a>
 * @version $Id: Generator.java 1592247 2014-05-03 16:38:36Z hboutemy $
 */
public interface Generator
{

    /**
     * Execute the generation for a given plugin descriptor.
     *
     * @param destinationDirectory required
     * @param request required
     * @throws GeneratorException if any
     * 
     * @since 2.5
     */
    void execute( File destinationDirectory, PluginToolsRequest request )
        throws GeneratorException;
}
